===============
handle_igblastn
===============

Overview
--------

Handle igblastn.

Installation
------------

To install handle_igblastn, you can use `pip`. Open your terminal and run:

.. code-block:: bash

    pip install handle_igblastn

License
-------

This project is licensed under the MIT License.

Credits
-------
- Author: Johannes Programming
- Email: johannes-programming@posteo.org

Thank you for using handle_igblastn!